@@ -23,24 +23,24 @@ import Data.ByteString
  
 compile ::
         RunMode ->
-          String -> String -> [[ByteString]] -> String -> Maybe String -> Map.Map String Int -> ImperativeMonad CompileResult
-compile theRunMode text templates tabs mytitle mylanguage formulas
+          String -> String -> [[ByteString]] -> String -> Maybe String -> Map.Map String Int -> Bool ->ImperativeMonad CompileResult 
+compile theRunMode text templates tabs mytitle mylanguage formulas b
   = do st <- get
        case theRunMode of
            StandardTemplates -> return
-                                  (run mylanguage mytitle (parseit parsers text) (parseit parsers text) (hostname . fullUrl $ st) templates
+                                  (run b mylanguage mytitle (parseit parsers text) (parseit parsers text) (hostname . fullUrl $ st) templates
                                      tabs formulas)
            UserTemplateFile _ -> return
-                                   (run mylanguage mytitle (parseit parsers text) (parseit parsers text) (hostname . fullUrl $ st) templates
+                                   (run b mylanguage mytitle (parseit parsers text) (parseit parsers text) (hostname . fullUrl $ st) templates
                                       tabs formulas)
            HTML -> do
                     return
-                     (run mylanguage mytitle (printPrepareTree (parseit minparsers text)) (printPrepareTree (parseit htmlminparsers text))
+                     (run b mylanguage mytitle (printPrepareTree (parseit minparsers text)) (printPrepareTree (parseit minparsers text))
                         (hostname . fullUrl $ st)
                         templates
                         tabs formulas)
            ExpandedTemplates -> return
-                                  (run mylanguage mytitle (parseit parsers text) (parseit parsers text) (hostname . fullUrl $ st) templates
+                                  (run b mylanguage mytitle (parseit parsers text) (parseit parsers text) (hostname . fullUrl $ st) templates
                                      tabs formulas)
  
 {-DHUN| pathname of the temporary directory of the compiler |DHUN-}
@@ -114,11 +114,11 @@ data CompileResult = CompileResult{images :: [String],
 {-DHUN| the first parameter is the parse tree created by get parse of the document currently being processed. the second parameter is the URL under which the document was downloaded. the third parameter is the netloc describing the wiki this page belongs to. The fourth parameter is a mapping file defined by the user for the mapping of mediawiki templates to latex commands. the fifth parameter is a possible parse tree created by precious run the the should be added before the begging of the newly created parse tree. This function writes out all results to temporary files that will be further processed by compiler.py DHUN-}
  
 run ::
-    Maybe String -> String -> [Anything Char] -> [Anything Char] ->
+    Bool -> Maybe String -> String -> [Anything Char] -> [Anything Char] ->
       String -> String -> [[ByteString]] -> Map.Map String Int-> CompileResult
-run mylanguage mytitle  parsetree parsetree2 netloc tmpl someTables formulas
+run bb mylanguage mytitle  parsetree parsetree2 netloc tmpl someTables formulas
   = CompileResult{images = img, body = bdy, tablelist = theTables,
-                  galleryNumbers = gals, title = tit, html=trda3}
+                  galleryNumbers = gals, title = tit, html=if bb then trda3 else []}
   where alldata2 g u
           = (treeToLaTeX3 ((snd . newtree $ g))
                initialState{urld = analyseNetloc netloc}{tabmap = u,
