@@ -44,15 +44,15 @@ fontsetter f
                ComputerModernTypeWriter, ComputerModernTypeWriterBold,
                ComputerModernTypeWriterItalic, ComputerModernTypeWriterBoldItalic]
             =
-            ",UprightFont=cmunrm.ttf,BoldFont=cmunbx.ttf" ++
-              ",ItalicFont=cmunti.ttf,BoldItalicFont=cmunbi.ttf"
+            ",UprightFont=cmunrm,BoldFont=cmunbx" ++
+              ",ItalicFont=cmunti,BoldItalicFont=cmunbi"
         mid i
           | i `elem`
               [FreeSerif, FreeSerifBold, FreeSerifBoldItalic, FreeSerifItalic,
                FreeMono, FreeMonoOblique, FreeMonoBold, FreeMonoBoldOblique]
             =
-            ",UprightFont=FreeSerif.ttf,BoldFont=FreeSerifBold.ttf," ++
-              "ItalicFont=FreeSerifItalic.ttf,BoldItalicFont=FreeSerifBoldItalic.ttf"
+            ",UprightFont=FreeSerif,BoldFont=FreeSerifBold," ++
+              "ItalicFont=FreeSerifItalic,BoldItalicFont=FreeSerifBoldItalic"
         mid _ = ""
         midmono i
           | i `elem`
@@ -61,15 +61,15 @@ fontsetter f
                ComputerModernTypeWriter, ComputerModernTypeWriterBold,
                ComputerModernTypeWriterItalic, ComputerModernTypeWriterBoldItalic]
             =
-            ",UprightFont=cmuntt.ttf,BoldFont=cmuntb.ttf" ++
-              ",ItalicFont=cmunit.ttf,BoldItalicFont=cmuntx.ttf"
+            ",UprightFont=cmuntt,BoldFont=cmuntb" ++
+              ",ItalicFont=cmunit,BoldItalicFont=cmuntx"
         midmono i
           | i `elem`
               [FreeSerif, FreeSerifBold, FreeSerifBoldItalic, FreeSerifItalic,
                FreeMono, FreeMonoOblique, FreeMonoBold, FreeMonoBoldOblique]
             =
-            ",UprightFont=FreeMono.ttf,BoldFont=FreeMonoBold.ttf," ++
-              "ItalicFont=FreeMonoOblique.ttf,BoldItalicFont=FreeMonoBoldOblique.ttf"
+            ",UprightFont=FreeMono,BoldFont=FreeMonoBold," ++
+              "ItalicFont=FreeMonoOblique,BoldItalicFont=FreeMonoBoldOblique"
         midmono _ = ""
  
 {-DHUN| Takes a FontStyle and returns the LaTeX Command to switch to that font. DHUN-}
