@@ -16,6 +16,7 @@ data MyError = DownloadError String String
              | NotIntegerPairError String
              | NotAtMostOneError String
              | ToManyOptionsError
+             | ToManyOutputOptionsError
              | PaperError
  
 type MyErrorMonad = Either MyError 
@@ -34,6 +35,8 @@ instance Show MyError where
           = "Error: The option paper may only be one of A4,A5,B5,letter,legal,executive"
         show ToManyOptionsError
           = "Error: at most one of the options --internal --templates --message --html may be given"
+        show ToManyOutputOptionsError
+          = "Error: at most one of the options --zip --epub --odt may be given"
         show (NotExcatlyOneError msg)
           = "Error: The option --" ++
               msg ++ " has to be present exactly once in the command line"
@@ -74,13 +77,13 @@ data RunMode = HTML
              | ExpandedTemplates
              | StandardTemplates
              | UserTemplateFile String
-             deriving (Show, Read)
+             deriving (Show, Read, Eq)
  
 data SourceMode = Included
                 | Excluded
                 deriving (Show, Read)
  
-data OutputType = PlainPDF | ZipArchive
+data OutputType = PlainPDF | ZipArchive | EPubFile | OdtFile
                 deriving (Show, Read,Eq)
 data FullConfig = FullConfig{headers :: Maybe String,
                              resolution :: Integer, outputFilename :: String,
