@@ -201,6 +201,24 @@ makeHeader fullurl m
               "\\begin{longtable}{rp{0.6\\linewidth}}\n" ++
                 "\\textbf{Edits}&\\textbf{User}\\\\\n"
  
+makeHeaderHTML :: FullWikiUrl -> Maybe String -> [Char]
+makeHeaderHTML fullurl m
+  = let mmm = m >>= (\ yy -> Map.lookup yy langau) in
+      "<h2>" ++
+        (case
+           mmm `mplus`
+             (case splitOn "." (hostname fullurl) of
+                  (x : _) -> Map.lookup x langau
+                  _ -> Nothing)
+             `mplus` (Map.lookup "en" langau)
+           of
+             Just x -> x
+             _ -> "Contributors")
+          ++
+          "</h2>\n" ++
+            "<table rules=\"all\">" ++
+                "<tr><td>Edits</td><td>User</td></tr>"
+
 makeBody :: (Ord t) => Map t Contributor -> URL -> [Char]
 makeBody m u = concat (map go (sort (toList m)))
   where fun ('/' : xs) = xs
@@ -212,7 +230,18 @@ makeBody m u = concat (map go (sort (toList m)))
                    (map chartransforlink (exportURL (u{url_path = (fun (href v))}))))
                   ++ "}{" ++ (concat (map chartrans (name v))) ++ "}\\\\\n"
  
-makeContributors :: Maybe URL -> ImperativeMonad String
+makeBodyHTML :: (Ord t) => Map t Contributor -> URL -> [Char]
+makeBodyHTML m u = concat (map go (sort (toList m)))
+  where fun ('/' : xs) = xs
+        fun xs = xs
+        go (_, v)
+          = "<tr><td>"++(show (edits v)) ++
+              "</td><td><a href=\"" ++
+                (((exportURL (u{url_path = (fun (href v))}))))
+                  ++ "\">" ++ (concat (map chartrans (name v))) ++ "</a></td></tr>"
+
+
+makeContributors :: Maybe URL -> ImperativeMonad (String, String)
 makeContributors uu
   = do st <- get
        li <- liftIO (mapM readMVar (audict st))
@@ -226,10 +255,11 @@ makeContributors uu
              = case (deepGet2 "html" (parseit minparsers yy)) of
                    ((Environment Tag (TagAttr _ m) _) : []) -> Map.lookup "lang" m
                    _ -> Nothing
-       return
+       return (
          ((makeHeader (fullUrl st) lang) ++
             (makeBody (myaudict) (url (fullUrl st))) ++
-              "\\end{longtable}\n" ++ "\\pagebreak\n")
+              "\\end{longtable}\n" ++ "\\pagebreak\n"),(makeHeaderHTML (fullUrl st) lang) ++
+            (makeBodyHTML (myaudict) (url (fullUrl st))) ++"</table>")
  
 parseUrl :: String -> ImperativeMonad FullWikiUrl
 parseUrl u
