@@ -35,91 +35,104 @@ data Flag = Verbose
           | InternalTemplates
           | Hex String
           | Zip
+          | EPub
+          | Odt
           | Server String
           deriving (Show, Eq)
  
-{-DHUN| String constant on for the version commad line option. DHUN-}
+{-DHUN| String constant on for the version command line option. DHUN-}
  
 versionOption :: String
 versionOption = "version"
 
-{-DHUN| String constant on for the featured commad line option. DHUN-}
+{-DHUN| String constant on for the featured command line option. DHUN-}
 
 featuredOption :: String
 featuredOption = "featured"
 
  
-{-DHUN| String constant on for the resolution commad line option. DHUN-}
+{-DHUN| String constant on for the resolution command line option. DHUN-}
  
 resolutionOption :: String
 resolutionOption = "resolution"
  
-{-DHUN| String constant on for the output commad line option. DHUN-}
+{-DHUN| String constant on for the output command line option. DHUN-}
  
 output :: String
 output = "output"
 
-{-DHUN| String constant on for the zip commad line option. DHUN-}
+{-DHUN| String constant on for the zip command line option. DHUN-}
  
 zip :: String
 zip = "zip"
 
  
-{-DHUN| String constant on for the hex commad line option. DHUN-}
+{-DHUN| String constant on for the hex command line option. DHUN-}
  
 hexen :: String
 hexen = "hex"
  
-{-DHUN| String constant on for the templates commad line option. DHUN-}
+{-DHUN| String constant on for the templates command line option. DHUN-}
  
 templates :: String
 templates = "templates"
  
-{-DHUN| String constant on for the headers commad line option. DHUN-}
+{-DHUN| String constant on for the headers command line option. DHUN-}
  
 headers :: String
 headers = "headers"
  
-{-DHUN| String constant on for the url commad line option. DHUN-}
+{-DHUN| String constant on for the url command line option. DHUN-}
  
 url :: String
 url = "url"
  
-{-DHUN| String constant on for the medaiwiki commad line option. DHUN-}
+{-DHUN| String constant on for the medaiwiki command line option. DHUN-}
  
 mediawiki :: String
 mediawiki = "mediawiki"
  
-{-DHUN| String constant on for the html commad line option. DHUN-}
+{-DHUN| String constant on for the html command line option. DHUN-}
  
 html :: String
 html = "html"
  
-{-DHUN| String constant on for the paper commad line option. DHUN-}
+{-DHUN| String constant on for the paper command line option. DHUN-}
  
 paperOption :: String
 paperOption = "paper"
  
-{-DHUN| String constant on for the internal commad line option. DHUN-}
+{-DHUN| String constant on for the internal command line option. DHUN-}
  
 internal :: String
 internal = "internal"
  
-{-DHUN| String constant on for the vector commad line option. DHUN-}
+{-DHUN| String constant on for the vector command line option. DHUN-}
  
 vectorOption :: String
 vectorOption = "vector"
  
-{-DHUN| String constant on for the copy commad line option. DHUN-}
+{-DHUN| String constant on for the copy command line option. DHUN-}
  
 copyOption :: String
 copyOption = "copy"
  
-{-DHUN| String constant on for the server commad line option. DHUN-}
+{-DHUN| String constant on for the server command line option. DHUN-}
  
 serverOption :: String
 serverOption = "server"
+
+{-DHUN| String constant on for the epub command line option. DHUN-}
  
+epubOption :: String
+epubOption = "epub"
+
+{-DHUN| String constant on for the odt command line option. DHUN-}
+ 
+odtOption :: String
+odtOption = "odt"
+
+
 {-DHUN| Datastructure describing all possible command line options DHUN-}
  
 options :: [OptDescr Flag]
@@ -147,6 +160,10 @@ options
        "use MediaWiki generated html as input (default)",
      Option ['z'] [Main.zip] (NoArg Main.Zip)
        "output zip archive of latex source",
+     Option ['b'] [epubOption] (NoArg Main.EPub)
+       "output epub file",
+     Option ['d'] [odtOption] (NoArg Main.Odt)
+       "output odt file",
      Option ['g'] [vectorOption] (NoArg Main.Vector)
        "keep vector graphics in vector form",
      Option ['i'] [internal] (NoArg Main.InternalTemplates)
@@ -174,7 +191,7 @@ header = "Usage: mediawiki2latex [OPTION...]"
  
 versionHeader :: String
 versionHeader
-  = "mediawiki2latex version 7.25\n" ++ (usageInfo header options)
+  = "mediawiki2latex version 7.27\n" ++ (usageInfo header options)
  
 {-DHUN| print the version string of mediawiki2latex. Takes the output of the compilerOpts function as input. Prints the version string if no options were given or the version command was given does noting otherwise DHUN-}
  
@@ -338,6 +355,8 @@ checkOpts cwd o
                                let mediaWikiVal = (MediaWiki `elem` o)
                                let htmlVal = (Main.HTML `elem` o)
                                let zipVal = (Main.Zip `elem` o)
+                               let epubVal = (Main.EPub `elem` o)
+                               let odtVal = (Main.Odt `elem` o)
                                let temVal = (Main.InternalTemplates `elem` o)
                                let vectorVal = (Main.Vector `elem` o)
                                let mysum
@@ -345,6 +364,7 @@ checkOpts cwd o
                                          (boolToInt htmlVal)
                                          + (maybeToInt templatesVal)
                                if mysum > 1 then Left ToManyOptionsError else Right ()
+                               if ((boolToInt zipVal) + (boolToInt epubVal) + (boolToInt odtVal)) > (1 :: Integer) then Left ToManyOutputOptionsError else Right ()
                                runModeVal <- if mysum == (1 :: Integer) then
                                                case templatesVal of
                                                    Just xx -> Right (UserTemplateFile xx)
@@ -361,7 +381,7 @@ checkOpts cwd o
                                              paper = paperVal, vector = vectorVal,
                                              copy = copyVal >>= (return . (cwd </>)),
                                              mainPath = cwd ++ (if os == "linux" then "" else "\\"),
-                                             server = Nothing, outputType=if zipVal then ZipArchive else PlainPDF})
+                                             server = Nothing, outputType=if zipVal then ZipArchive else if epubVal then EPubFile else if odtVal then OdtFile else PlainPDF})
  
 {-DHUN| main entry point of mediawiki2latex DHUN-}
  
